###########
Django Cool
###########

Django 快速使用框架


安装与升级
==========

目前 Django Cool 支持的 Python 环境有 3.6, 3.7, 3.8 和 pypy
支持 Django 版本 2.2, 3.0

为了简化安装过程，推荐使用 pip 进行安装

.. code-block:: bash

    pip install django-cool

升级 Django Cool 到新版本::

    pip install -U django-cool

如果需要安装 GitHub 上的最新代码::

    pip install https://github.com/007gzs/django-cool/archive/master.zip


示例项目
========

`demo项目 <https://github.com/007gzs/django-cool-example/>`_

